/* OGMRip - A library for DVD ripping and encoding
 * Copyright (C) 2004-2008 Olivier Rolland <billl@users.sf.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMRIP_MP3_H__
#define __OGMRIP_MP3_H__

#include <ogmrip-audio-codec.h>

G_BEGIN_DECLS

#define OGMRIP_TYPE_MP3          (ogmrip_mp3_get_type ())
#define OGMRIP_MP3(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), OGMRIP_TYPE_MP3, OGMRipMp3))
#define OGMRIP_MP3_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST ((klass), OGMRIP_TYPE_MP3, OGMRipMp3Class))
#define OGMRIP_IS_MP3(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OGMRIP_TYPE_MP3))
#define OGMRIP_IS_MP3_CLASS(obj) (G_TYPE_CHECK_CLASS_TYPE ((klass), OGMRIP_TYPE_MP3))

typedef struct _OGMRipMp3      OGMRipMp3;
typedef struct _OGMRipMp3Class OGMRipMp3Class;

struct _OGMRipMp3
{
  OGMRipAudioCodec parent_instance;
};

struct _OGMRipMp3Class
{
  OGMRipAudioCodecClass parent_class;
};

GType         ogmrip_mp3_get_type  (void);
OGMJobSpawn * ogmrip_mp3_new       (OGMDvdAudioStream *audio,
                                    const gchar       *output);

G_END_DECLS

#endif /* __OGMRIP_MP3_H__ */

